@@ -5,7 +5,7 @@
 // This file is licensed under the GPLv2 or later
 //
 // Copyright 2010 Hib Eris <hib@hiberis.nl>
-// Copyright 2010 Albert Astals Cid <aacid@kde.org>
+// Copyright 2010, 2022 Albert Astals Cid <aacid@kde.org>
 // Copyright 2010 Jonathan Liu <net147@gmail.com>
 // Copyright 2021 Peter Williams <peter@newton.cx>
 // Copyright 2021 Christian Persch <chpe@src.gnome.org>
@@ -23,11 +23,12 @@
 
 FILECacheLoader::~FILECacheLoader()
 {
-    if (file != stdin)
+    if (file != stdin) {
         fclose(file);
+    }
 }
 
-size_t FILECacheLoader::init(GooString *dummy, CachedFile *cachedFile)
+size_t FILECacheLoader::init(CachedFile *cachedFile)
 {
     size_t read, size = 0;
     char buf[CachedFileChunkSize];
